summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorRinnegatamante2017-07-25 12:15:42 +0200
committerRinnegatamante2017-07-25 12:15:42 +0200
commit48761273b8d62a9d75df8b62fbe448f1734bee5b (patch)
tree966c1fc026156c00f8357ceb18c62f54250f724b
parentRe-added SCE_CTRL_INTERCEPTED. (diff)
downloadvds-libraries-48761273b8d62a9d75df8b62fbe448f1734bee5b.tar.gz
Minor stylistic changes.
Diffstat (limited to '')
-rw-r--r--include/kernel/ctrl.h55
-rw-r--r--include/user/ctrl.h46
2 files changed, 51 insertions, 50 deletions
diff --git a/include/user/ctrl.h b/include/user/ctrl.h
index 3399f99..1261dd3 100644
--- a/include/user/ctrl.h
+++ b/include/user/ctrl.h
@@ -15,32 +15,32 @@ typedef enum SceCtrlErrorCode {
} SceCtrlErrorCode;
/** Enumeration for the digital controller buttons.
- * @note - L1/R1/L3/R3 only can bind using sceCtrlReadBufferPositiveExt2
+ * @note - L1/R1/L3/R3 only can bind using ::sceCtrlReadBufferPositiveExt2
* @note - Values bigger than 0x00010000 can be intercepted only with shell privileges
*/
typedef enum SceCtrlButtons {
- SCE_CTRL_SELECT = 0x00000001, //!< Select button.
- SCE_CTRL_L3 = 0x00000002, //!< L3 button.
- SCE_CTRL_R3 = 0x00000004, //!< R3 button.
- SCE_CTRL_START = 0x00000008, //!< Start button.
- SCE_CTRL_UP = 0x00000010, //!< Up D-Pad button.
- SCE_CTRL_RIGHT = 0x00000020, //!< Right D-Pad button.
- SCE_CTRL_DOWN = 0x00000040, //!< Down D-Pad button.
- SCE_CTRL_LEFT = 0x00000080, //!< Left D-Pad button.
- SCE_CTRL_LTRIGGER = 0x00000100, //!< Left trigger.
- SCE_CTRL_RTRIGGER = 0x00000200, //!< Right trigger.
- SCE_CTRL_L1 = 0x00000400, //!< L1 button.
- SCE_CTRL_R1 = 0x00000800, //!< R1 button.
- SCE_CTRL_TRIANGLE = 0x00001000, //!< Triangle button.
- SCE_CTRL_CIRCLE = 0x00002000, //!< Circle button.
- SCE_CTRL_CROSS = 0x00004000, //!< Cross button.
- SCE_CTRL_SQUARE = 0x00008000, //!< Square button.
- SCE_CTRL_INTERCEPTED = 0x00010000, //!< Input not available because intercepted by another application
- SCE_CTRL_PSBUTTON = 0x00010000, //!< Playstation (Home) button.
- SCE_CTRL_HEADPHONE = 0x00080000, //!< Headphone plugged in.
- SCE_CTRL_VOLUP = 0x00100000, //!< Volume up button.
- SCE_CTRL_VOLDOWN = 0x00200000, //!< Volume down button.
- SCE_CTRL_POWER = 0x40000000 //!< Power button.
+ SCE_CTRL_SELECT = 0x00000001, //!< Select button.
+ SCE_CTRL_L3 = 0x00000002, //!< L3 button.
+ SCE_CTRL_R3 = 0x00000004, //!< R3 button.
+ SCE_CTRL_START = 0x00000008, //!< Start button.
+ SCE_CTRL_UP = 0x00000010, //!< Up D-Pad button.
+ SCE_CTRL_RIGHT = 0x00000020, //!< Right D-Pad button.
+ SCE_CTRL_DOWN = 0x00000040, //!< Down D-Pad button.
+ SCE_CTRL_LEFT = 0x00000080, //!< Left D-Pad button.
+ SCE_CTRL_LTRIGGER = 0x00000100, //!< Left trigger.
+ SCE_CTRL_RTRIGGER = 0x00000200, //!< Right trigger.
+ SCE_CTRL_L1 = 0x00000400, //!< L1 button.
+ SCE_CTRL_R1 = 0x00000800, //!< R1 button.
+ SCE_CTRL_TRIANGLE = 0x00001000, //!< Triangle button.
+ SCE_CTRL_CIRCLE = 0x00002000, //!< Circle button.
+ SCE_CTRL_CROSS = 0x00004000, //!< Cross button.
+ SCE_CTRL_SQUARE = 0x00008000, //!< Square button.
+ SCE_CTRL_INTERCEPTED = 0x00010000, //!< Input not available because intercepted by another application
+ SCE_CTRL_PSBUTTON = SCE_CTRL_INTERCEPTED, //!< Playstation (Home) button.
+ SCE_CTRL_HEADPHONE = 0x00080000, //!< Headphone plugged in.
+ SCE_CTRL_VOLUP = 0x00100000, //!< Volume up button.
+ SCE_CTRL_VOLDOWN = 0x00200000, //!< Volume down button.
+ SCE_CTRL_POWER = 0x40000000 //!< Power button.
} SceCtrlButtons;
/** Enumeration for the controller types. */
diff --git a/include/kernel/ctrl.h b/include/kernel/ctrl.h
index 34bea51..bfc29a8 100644
--- a/include/kernel/ctrl.h
+++ b/include/kernel/ctrl.h
@@ -14,31 +14,32 @@ enum {
};
/** Enumeration for the digital controller buttons.
- * L1/R1/L3/R3 only can bind using sceCtrlReadBufferPositiveExt2 */
-enum SceCtrlPadButtons {
- SCE_CTRL_SELECT = 0x00000001, //!< Select button.
- SCE_CTRL_L3 = 0x00000002, //!< L3 button.
- SCE_CTRL_R3 = 0x00000004, //!< R3 button.
- SCE_CTRL_START = 0x00000008, //!< Start button.
- SCE_CTRL_UP = 0x00000010, //!< Up D-Pad button.
- SCE_CTRL_RIGHT = 0x00000020, //!< Right D-Pad button.
- SCE_CTRL_DOWN = 0x00000040, //!< Down D-Pad button.
- SCE_CTRL_LEFT = 0x00000080, //!< Left D-Pad button.
- SCE_CTRL_LTRIGGER = 0x00000100, //!< Left trigger.
- SCE_CTRL_RTRIGGER = 0x00000200, //!< Right trigger.
- SCE_CTRL_L1 = 0x00000400, //!< L1 button.
- SCE_CTRL_R1 = 0x00000800, //!< R1 button.
- SCE_CTRL_TRIANGLE = 0x00001000, //!< Triangle button.
- SCE_CTRL_CIRCLE = 0x00002000, //!< Circle button.
- SCE_CTRL_CROSS = 0x00004000, //!< Cross button.
- SCE_CTRL_SQUARE = 0x00008000, //!< Square button.
- SCE_CTRL_INTERCEPTED = 0x00010000, //!< Input not available because intercepted by another application
- SCE_CTRL_PSBUTTON = 0x00010000, //!< Playstation (Home) button.
- SCE_CTRL_HEADPHONE = 0x00080000, //!< Headphone plugged in.
- SCE_CTRL_VOLUP = 0x00100000, //!< Volume up button.
- SCE_CTRL_VOLDOWN = 0x00200000, //!< Volume down button.
- SCE_CTRL_POWER = 0x40000000 //!< Power button.
-};
+ * @note - L1/R1/L3/R3 only can bind using ::sceCtrlReadBufferPositiveExt2
+ */
+typedef enum SceCtrlButtons {
+ SCE_CTRL_SELECT = 0x00000001, //!< Select button.
+ SCE_CTRL_L3 = 0x00000002, //!< L3 button.
+ SCE_CTRL_R3 = 0x00000004, //!< R3 button.
+ SCE_CTRL_START = 0x00000008, //!< Start button.
+ SCE_CTRL_UP = 0x00000010, //!< Up D-Pad button.
+ SCE_CTRL_RIGHT = 0x00000020, //!< Right D-Pad button.
+ SCE_CTRL_DOWN = 0x00000040, //!< Down D-Pad button.
+ SCE_CTRL_LEFT = 0x00000080, //!< Left D-Pad button.
+ SCE_CTRL_LTRIGGER = 0x00000100, //!< Left trigger.
+ SCE_CTRL_RTRIGGER = 0x00000200, //!< Right trigger.
+ SCE_CTRL_L1 = 0x00000400, //!< L1 button.
+ SCE_CTRL_R1 = 0x00000800, //!< R1 button.
+ SCE_CTRL_TRIANGLE = 0x00001000, //!< Triangle button.
+ SCE_CTRL_CIRCLE = 0x00002000, //!< Circle button.
+ SCE_CTRL_CROSS = 0x00004000, //!< Cross button.
+ SCE_CTRL_SQUARE = 0x00008000, //!< Square button.
+ SCE_CTRL_INTERCEPTED = 0x00010000, //!< Input not available because intercepted by another application
+ SCE_CTRL_PSBUTTON = SCE_CTRL_INTERCEPTED, //!< Playstation (Home) button.
+ SCE_CTRL_HEADPHONE = 0x00080000, //!< Headphone plugged in.
+ SCE_CTRL_VOLUP = 0x00100000, //!< Volume up button.
+ SCE_CTRL_VOLDOWN = 0x00200000, //!< Volume down button.
+ SCE_CTRL_POWER = 0x40000000 //!< Power button.
+} SceCtrlButtons;
/** Enumeration for the controller types. */
enum SceCtrlExternalInputMode {
@@ -240,10 +241,10 @@ int sceCtrlGetButtonIntercept(int *intercept);
* @param port Use 0
* @param slot The slot used to set the custom values. Between 0 - 3. If multiple slots are used,
* their settings are combined.
* @param userButtons Emulated user buttons of ::SceCtrlPadButtons. You cannot emulate kernel
* buttons and the emulated buttons will only be applied for applications
* running in user mode.
* @param kernelButtons Emulated buttons of ::SceCtrlPadButtons (you can emulate both user and
* kernel buttons). The emulated buttons will only be applied for applications
* running in kernel mode.
* @param uiMake Specifies the duration of the emulation. Measured in sampling counts.
@@ -240,10 +241,10 @@ int sceCtrlGetButtonIntercept(int *intercept);
* @param slot The slot used to set the custom values. Between 0 - 3. If multiple slots are used,
* their settings are combined.
- * @param userButtons Emulated user buttons of ::SceCtrlPadButtons. You cannot emulate kernel
+ * @param userButtons Emulated user buttons of ::SceCtrlButtons. You cannot emulate kernel
* buttons and the emulated buttons will only be applied for applications
* running in user mode.
@@ -240,10 +241,10 @@ int sceCtrlGetButtonIntercept(int *intercept);
* buttons and the emulated buttons will only be applied for applications
* running in user mode.
- * @param kernelButtons Emulated buttons of ::SceCtrlPadButtons (you can emulate both user and
+ * @param kernelButtons Emulated buttons of ::SceCtrlButtons (you can emulate both user and
* kernel buttons). The emulated buttons will only be applied for applications
* running in kernel mode.